@@ -6,11 +6,4 @@ from shellfish._meta import __version__
 
 ps = process
 
-__all__ = (
-    "__version__",
-    # modules
-    "fs",
-    "ps",
-    "sh",
-    "dotenv",
-)
+__all__ = ("__version__", "dotenv", "fs", "process", "ps", "sh")
