@@ -22,6 +22,7 @@ from xtyping import (
     Iterable,
     Iterator,
     List,
+    Literal,
     Optional,
     Tuple,
     Union,
@@ -31,6 +32,7 @@ __all__ = (
     "dirpath_gen",
     "dirs_gen",
     "exists",
+    "extension",
     "file_lines_gen",
     "file_size",
     "filecmp",
@@ -60,6 +62,11 @@ __all__ = (
     "sbin",
     "sbytes",
     "scandir_list",
+    "sep_join",
+    "sep_lstrip",
+    "sep_rstrip",
+    "sep_split",
+    "sep_strip",
     "shebang",
     "sstr",
     "sstring",
@@ -674,11 +681,11 @@ def wbytes(
     bites: bytes,
     *,
     append: bool = False,
-) -> bool:
+) -> int:
     """Write/Save bytes to a fspath
 
-    The parameter 'bites' is used instead of 'bytes' so as to not redefine
-    the built-in python bytes object.
+    The parameter 'bites' is used instead of 'bytes' to not redefine the
+    built-in python bytes object.
 
     Args:
         filepath: fspath to write to
@@ -687,16 +694,16 @@ def wbytes(
             is False
 
     Returns:
-        None
+        int: Number of bytes written
 
     Examples:
         >>> from shellfish.fs import rbytes, wbytes
-        >>> fspath = "sbytes.doctest.txt"
+        >>> fspath = "wbytes.doctest.txt"
         >>> bites_to_save = b"These are some bytes"
         >>> bites_to_save  # they are bytes!
         b'These are some bytes'
         >>> wbytes(fspath, bites_to_save)
-        True
+        20
         >>> rbytes(fspath)
         b'These are some bytes'
         >>> import os; os.remove(fspath)
@@ -704,8 +711,8 @@ def wbytes(
     """
     _write_mode = "ab" if append else "wb"
     with open(filepath, _write_mode) as fd:
-        fd.write(bites)
-    return True
+        nbytes = fd.write(bites)
+    return nbytes
 
 
 def rbytes(filepath: FsPath) -> bytes:
@@ -719,10 +726,10 @@ def rbytes(filepath: FsPath) -> bytes:
 
     Examples:
         >>> from shellfish.fs import rbytes, wbytes
-        >>> fspath = "lbytes.doctest.txt"
+        >>> fspath = "rbytes.doctest.txt"
         >>> bites_to_save = b"These are some bytes"
         >>> wbytes(fspath, bites_to_save)
-        True
+        20
         >>> bites_to_save  # they are bytes!
         b'These are some bytes'
         >>> rbytes(fspath)
@@ -751,6 +758,7 @@ def file_lines_gen(filepath: FsPath, keepends: bool = True) -> Iterable[str]:
         >>> fspath = "file_lines_gen.doctest.txt"
         >>> from shellfish.fs import wstring
         >>> wstring(fspath, string)
+        17
         >>> for file_line in file_lines_gen(fspath):
         ...     file_line
         '1\n'
@@ -794,11 +802,11 @@ def rbytes_gen(filepath: FsPath, blocksize: int = 65536) -> Iterable[bytes]:
             yield data
 
 
-def sbytes_gen(
+def wbytes_gen(
     filepath: FsPath,
     bytes_gen: Iterable[bytes],
     append: bool = False,
-) -> None:
+) -> int:
     """Write/Save bytes to a fspath
 
     Args:
@@ -806,26 +814,27 @@ def sbytes_gen(
         bytes_gen: Bytes to be written
         append (bool): Append to the file if True, overwrite otherwise; default
             is False
-        flags: Flags to write the file with (OS dependent)
-        mode: Mode/permissions to save json file with
+
+    Returns:
+        int: Number of bytes written
 
     Examples:
         >>> from shellfish.fs import rbytes, wbytes
         >>> fspath = "wbytes_gen.doctest.txt"
-        >>> bites_to_save = b"These are some bytes"
+        >>> bites_to_save = (b"These are some bytes... ", b"more bytes!")
         >>> bites_to_save  # they are bytes!
-        b'These are some bytes'
-        >>> wbytes(fspath, bites_to_save)
-        True
+        (b'These are some bytes... ', b'more bytes!')
+        >>> wbytes_gen(fspath, (b for b in bites_to_save))
+        35
         >>> rbytes(fspath)
-        b'These are some bytes'
+        b'These are some bytes... more bytes!'
         >>> import os; os.remove(fspath)
 
     """
-    _write_mode = "ab" if append else "wb"
-    with open(filepath, _write_mode) as fd:
-        for chunk in bytes_gen:
-            fd.write(chunk)
+    _mode: Literal["ab", "wb"] = "ab" if append else "wb"
+    with open(filepath, mode=_mode) as fd:
+        nbytes_written = sum(fd.write(chunk) for chunk in bytes_gen)
+    return nbytes_written
 
 
 def rstring(filepath: FsPath) -> str:
@@ -842,6 +851,7 @@ def rstring(filepath: FsPath) -> str:
         >>> from shellfish.fs import rstring, wstring
         >>> fspath = "lstring.doctest.txt"
         >>> sstring(fspath, r'Check out this string')
+        21
         >>> lstring(fspath)
         'Check out this string'
         >>> import os; os.remove(fspath)
@@ -863,7 +873,7 @@ def wstring(
     *,
     encoding: str = "utf-8",
     append: bool = False,
-) -> None:
+) -> int:
     """Save/Write a string to fspath
 
     Args:
@@ -879,18 +889,49 @@ def wstring(
         >>> from shellfish.fs import rstring, wstring
         >>> fspath = "sstring.doctest.txt"
         >>> wstring(fspath, r'Check out this string')
+        21
         >>> rstring(fspath)
         'Check out this string'
         >>> import os; os.remove(fspath)
 
     """
-    sbytes(
+    return wbytes(
         filepath=filepath,
         bites=string.encode(encoding),
         append=append,
     )
 
 
+def extension(fspath: str) -> str:
+    """Return the extension for a fspath"""
+    return "".join(Path(fspath).suffixes).lstrip(".")
+
+
+def sep_split(fspath: FsPath) -> Tuple[str, ...]:
+    """Split a string on the current platform os.path.sep value"""
+    return tuple((el for el in str(fspath).split(sep) if el != sep and el != ""))
+
+
+def sep_join(path_strings: Iterator[str]) -> str:
+    """Join iterable of strings on the current platform os.path.sep value"""
+    return sep.join(path_strings)
+
+
+def sep_strip(fspath: FsPath) -> str:
+    """Strip a string of the current platform's os.path.sep value"""
+    return str(fspath).strip(sep)
+
+
+def sep_lstrip(fspath: FsPath) -> str:
+    """Left-strip a string of the current platform's os.path.sep value"""
+    return str(fspath).lstrip(sep)
+
+
+def sep_rstrip(fspath: FsPath) -> str:
+    """Right-strip a string of the current platform's os.path.sep value"""
+    return str(fspath).rstrip(sep)
+
+
 def filecmp(
     left: FsPath,
     right: FsPath,
@@ -929,19 +970,11 @@ def filecmp(
     )
 
 
-# IO function aliases
-lbytes = rbin = lbin = rbytes
-sbytes = wbin = sbin = wbytes
-lstring = rstr = lstr = rstring
-sstring = wstr = sstr = wstring
-lbytes_gen = rbin_gen = rbytes_gen
-
-
 def shebang(fspath: FsPath) -> Union[None, str]:
     r"""Get the shebang string given a fspath; Returns None if no shebang
 
     Args:
-        fspath (str): Path to file that might have a shebang
+        fspath (fspath): Path to file that might have a shebang
 
     Returns:
         Optional[str]: The shebang string if it exists, None otherwise
@@ -963,6 +996,15 @@ def shebang(fspath: FsPath) -> Union[None, str]:
         return first if "#!" in first[:2] else None
 
 
+# IO function aliases
+lbytes = rbin = lbin = rbytes
+sbytes = wbin = sbin = wbytes
+lstring = rstr = lstr = rstring
+sstring = wstr = sstr = wstring
+lbytes_gen = rbin_gen = rbytes_gen
+sbytes_gen = wbin_gen = wbytes_gen
+
+
 if __name__ == "__main__":
     from doctest import testmod
 
